@@ -8,9 +8,6 @@
 ## usethis namespace: end
 NULL
 
-sexp_address <- NULL
-
 .onLoad <- function(lib, pkg) {
-  # FIXME: Export from rlang
-  sexp_address <<- env_get(ns_env("rlang"), "sexp_address")
+  run_on_load()
 }
